@@ -991,6 +991,10 @@ gboolean rm_digest_equal(RmDigest *a, RmDigest *b) {
         return false;
     }
 
+    if(a->bytes == 0) {
+        return true; /* this non-sense is used in replays */
+    }
+
     if(a->type == RM_DIGEST_PARANOID) {
         RmParanoid *pa = a->state;
         RmParanoid *pb = b->state;
@@ -1009,7 +1013,6 @@ gboolean rm_digest_equal(RmDigest *a, RmDigest *b) {
         /* all the "easy" ways failed... do manual check of all buffers */
         GSList *a_iter = pa->buffers;
         GSList *b_iter = pb->buffers;
-        guint bytes = 0;
         while(a_iter && b_iter) {
             if(!rm_buffer_equal(a_iter->data, b_iter->data)) {
                 rm_log_error_line(
@@ -1017,7 +1020,6 @@ gboolean rm_digest_equal(RmDigest *a, RmDigest *b) {
                     "shadow hash");
                 return false;
             }
-            bytes += ((RmBuffer *)a_iter->data)->len;
             a_iter = a_iter->next;
             b_iter = b_iter->next;
         }
