@@ -32,6 +32,10 @@
 
 #include <sys/ioctl.h>
 
+#if defined(__sun)
+#include <sys/termios.h>
+#endif
+
 typedef struct RmFmtHandlerSummary {
     /* must be first */
     RmFmtHandler parent;
