@@ -1,17 +1,15 @@
 #!/usr/bin/env python3
-# encoding: utf-8
-from nose import with_setup
+import csv
+
 from tests.utils import *
 
-import csv
 
 def csv_string_to_data(csv_dump):
     data = list(csv.reader(csv_dump.splitlines()))
     return data[1:]
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_simple():
+def test_simple(usual_setup_usual_teardown):
     create_file('1234', 'a')
     create_file('1234', 'b')
     create_file('1234', 'stupid\'file,name')
@@ -40,8 +38,7 @@ def test_simple():
 
 
 # regression test for GitHub issue #496
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_no_checksum():
+def test_no_checksum(usual_setup_usual_teardown):
     # rmlint will not (normally) hash files with no same-sized siblings
     create_file('x', 'a')
     create_file('yy', 'b')
