@@ -1,11 +1,8 @@
 #!/usr/bin/env python3
-# encoding: utf-8
-from nose import with_setup
 from tests.utils import *
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_simple():
+def test_simple(usual_setup_usual_teardown):
     full_path_a = create_file('x', '\t\r\"\b\f\\')
     full_path_b = create_file('x', '\"\t\n2134124')
     head, *data, footer = run_rmlint('-S a')
