@@ -1,10 +1,8 @@
 #!/usr/bin/env python3
 # encoding: utf-8
-from nose import with_setup
 from tests.utils import *
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_negative_with_basename():
+def test_negative_with_basename(usual_setup_usual_teardown):
     create_file('xxx', 'a')
     create_file('xxx', 'b')
     head, *data, footer = run_rmlint('-b')
@@ -13,8 +11,7 @@ def test_negative_with_basename():
     assert footer['duplicates'] == 0
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_positive_with_basename():
+def test_positive_with_basename(usual_setup_usual_teardown):
     create_file('xxx', 'a/test')
     create_file('xxx', 'b/test')
     head, *data, footer = run_rmlint('-b')
@@ -23,8 +20,7 @@ def test_positive_with_basename():
     assert footer['duplicates'] == 1
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_negative_without_basename():
+def test_negative_without_basename(usual_setup_usual_teardown):
     create_file('xxx', 'a/test')
     create_file('xxx', 'b/test')
     head, *data, footer = run_rmlint('-B')
@@ -33,8 +29,7 @@ def test_negative_without_basename():
     assert footer['duplicates'] == 0
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_positive_without_basename():
+def test_positive_without_basename(usual_setup_usual_teardown):
     create_file('xxx', 'a/test1')
     create_file('xxx', 'b/test2')
     head, *data, footer = run_rmlint('-B')
