@@ -1,7 +1,5 @@
 #!/usr/bin/env python3
 # encoding: utf-8
-from nose.plugins.attrib import attr
-from nose import with_setup
 from tests.utils import *
 
 import os
@@ -13,8 +11,7 @@ def set_mtime(path, mtime):
     subprocess.call(['touch', '-m', '-d', str(mtime), full_path])
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_consider_mtime():
+def test_consider_mtime(usual_setup_usual_teardown):
     create_file('xxx', 'a')
     create_file('xxx', 'b')
     create_file('xxx', 'c')
@@ -54,8 +51,7 @@ def test_consider_mtime():
     assert footer['duplicate_sets'] == 1
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_consider_mtime_subsecond():
+def test_consider_mtime_subsecond(usual_setup_usual_teardown):
     create_file('xxx', 'a')
     create_file('xxx', 'b')
 
@@ -74,8 +70,7 @@ def test_consider_mtime_subsecond():
     head, *data, footer = run_rmlint('--mtime-window=0')
     assert len(data) == 0
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_consider_mtime_fail_by_association():
+def test_consider_mtime_fail_by_association(usual_setup_usual_teardown):
     create_file('xxx', 'a')
     create_file('yyy', 'b')
     create_file('xxx', 'c')
@@ -92,8 +87,7 @@ def test_consider_mtime_fail_by_association():
     assert footer['duplicates'] == 0
     assert footer['duplicate_sets'] == 0
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_mtime_and_unmatched_basenames():
+def test_mtime_and_unmatched_basenames(usual_setup_usual_teardown):
     create_file('xxx', 'dir1/a')
     create_file('xxx', 'dir1/c')
     create_file('xxx', 'dir2/a')
