@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 # encoding: utf-8
-from nose import with_setup
 from tests.utils import *
 
 
@@ -11,8 +10,7 @@ def create_set():
         create_file('x' * 512, 'small' + suffix)
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_valid():
+def test_valid(usual_setup_usual_teardown):
     create_set()
 
     # Scalar:
@@ -50,8 +48,8 @@ def test_valid():
     *_, footer = run_rmlint('--size 1-18446744073709549K')
     assert footer['duplicates'] == 6
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_invalid():
+
+def test_invalid(usual_setup_usual_teardown):
     create_set()
 
     def trigger(*args):
@@ -64,7 +62,7 @@ def test_invalid():
             assert False
 
     # Not a valid range:
-    trigger('--size \-\-17')
+    trigger(r'--size --17')
 
     # max < min
     trigger('--size 10-9')
@@ -83,8 +81,7 @@ def test_invalid():
 
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_replay_size():
+def test_replay_size(usual_setup_usual_teardown):
     create_file('', 'empty1')
     create_file('', 'empty2')
     create_file('xxx', 'a/xxx')
