@@ -1,14 +1,10 @@
 #!/usr/bin/env python3
-# encoding: utf-8
-
 import os
 
-from nose import with_setup
 from tests.utils import *
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_default():
+def test_default(usual_setup_usual_teardown):
     # --see-symlinks should be on by default.
     create_file('xxx', 'a/z')
     create_link('a/z', 'a/x', symlink=True)
@@ -24,8 +20,7 @@ def test_default():
         '/a/z',
     }
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_merge_directories_with_ignored_symlinks():
+def test_merge_directories_with_ignored_symlinks(usual_setup_usual_teardown):
     # Badlinks should not forbid finding duplicate directories
     # when being filtered out during traversing with -T dd,df.
     create_file('xxx', 'a/z')
@@ -39,8 +34,7 @@ def test_merge_directories_with_ignored_symlinks():
         '/b',
     }
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_order():
+def test_order(usual_setup_usual_teardown):
     create_file('xxx', 'a/z')
     create_link('a/z', 'a/x', symlink=True)
     create_file('xxx', 'b/z')
@@ -83,8 +77,7 @@ def test_order():
     assert data[file_idx + 1]['path'].endswith('z')
 
 
-@with_setup(usual_setup_func, usual_teardown_func)
-def test_symlink_matches_file():
+def test_symlink_matches_file(usual_setup_usual_teardown):
     create_file('xxx', 'foo')
     create_file('foo', 'file')
     os.symlink('foo', os.path.join(TESTDIR_NAME, 'link'))
